
# Slot: evaluated using




URI: [http://example.org/sample/example1/evaluated_using](http://example.org/sample/example1/evaluated_using)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [MetricResult](MetricResult.md)
 * [MetricResultChild](MetricResultChild.md)
